<?php

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Get the input JSON
$data = json_decode(file_get_contents("php://input"), true);

// Log the received data for debugging
error_log(print_r($data, true));

// Define the admin and user email addresses
$admin_email = 'nick.walker@krazydesignlabs.com'; // Admin email
$user_email = $data['email']; // User email from input data

// Validate the data
if (isset($data['email'], $data['name'], $data['amount'], $data['description'])) {
    // Validate email format
    if (!filter_var($data['email'], FILTER_VALIDATE_EMAIL)) {
        echo json_encode(['status' => 'Invalid email format!', 'received_data' => $data]);
        exit;
    }

    // Validate amount is a number
    if (!is_numeric($data['amount'])) {
        echo json_encode(['status' => 'Amount must be a number!', 'received_data' => $data]);
        exit;
    }

    // Email subject and headers
    $headers = "MIME-Version: 1.0" . "\r\n";
    $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
    $headers .= 'From: noreply@yourdomain.com' . "\r\n"; // Sender email
    $headers .= 'Reply-To: noreply@yourdomain.com' . "\r\n"; // Optional reply-to

    // Message to the user
    $subject_user = 'Payment Confirmation';
    $message_user = "
    <html>
    <head>
        <title>Payment Confirmation</title>
    </head>
    <body>
        <h1>Payment Confirmation</h1>
        <p>Dear {$data['name']},</p>
        <p>Thank you for your payment of \${$data['amount']} for {$data['description']}.</p>
        <p>We appreciate your business!</p>
    </body>
    </html>
    ";

    // Send email to the user
    $user_email_status = mail($user_email, $subject_user, $message_user, $headers);
    if (!$user_email_status) {
        error_log("Failed to send email to user: $user_email");
    }

    // Message to the admin
    $subject_admin = 'New Payment Received';
    $message_admin = "
    <html>
    <head>
        <title>New Payment Notification</title>
    </head>
    <body>
        <h1>New Payment Notification</h1>
        <p>A payment of \${$data['amount']} has been received.</p>
        <p>Details:</p>
        <ul>
            <li>Customer Name: {$data['name']}</li>
            <li>Customer Email: {$data['email']}</li>
            <li>Description: {$data['description']}</li>
        </ul>
        <p>Thank you!</p>
    </body>
    </html>
    ";

    // Send email to the admin
    $admin_email_status = mail($admin_email, $subject_admin, $message_admin, $headers);
    if (!$admin_email_status) {
        error_log("Failed to send email to admin: $admin_email");
    }

    // Check both email statuses
    if ($user_email_status && $admin_email_status) {
        echo json_encode(['status' => 'Emails sent successfully to both user and admin!']);
    } else {
        echo json_encode(['status' => 'One or more emails failed to send!']);
    }
} else {
    echo json_encode(['status' => 'Invalid data!', 'received_data' => $data]);
}
?>
